[**Opções avançadas**](./introduction.md) > **Código do idioma** _(atual)_

---

#### Google

Fonte <https://developers.google.com/admin-sdk/directory/v1/languages?hl=zh-cn>, organizado por GPT-4o.

| Rótulo em chinês | Rótulo | `Código do idioma` |
| --- | --- | --- |
| Amárico | Amharic | `am` |
A tabela traduzida para português é:

| Árabe | Arabic | `ar` |
| Basco | `eu` |
| Bengali | Bengali | `bn` |
| Inglês (Reino Unido) | English (UK) | `en-GB` |
| Português (Brasil) | Portuguese (Brazil) | `pt-BR` |
| Búlgaro | Bulgarian | `bg` |
| Catalão | Catalan | `ca` |
| 切罗基语 | Cherokee | `chr` |
| Croata | Croatian | `hr` |
| Tcheco | Czech | `cs` |
| Dinamarquês | Danish | `da` |
| 荷兰语 | Dutch | `nl` |
| Português (Brasil) | Portuguese (Brazil) | `pt` |
| 爱沙尼亚语 | Estonian | `et` |
| Filipino | `fil` |
| 芬兰语 | Finnish | `fi` |
| Francês | French | `fr` |
| Alemão | German | `de` |
| Grego | `el` |
| Gujarati | Gujarati | `gu` |
| Hebraico | `iw` |
| Hindi | Hindi | `hi` |
| Húngaro | Hungarian | `hu` |
| 冰岛语 | Icelandic | `is` |
| Indonésio | Indonesian | `id` |
| Italiano | Italian | `it` |
| Japonês | Japanese | `ja` |
| 卡纳达语 | Kannada | `kn` |
| Coreano | `ko` |
| Letão | Latvian | `lv` |
| Lituano | Lithuanian | `lt` |
| Malaio | Malay | `ms` |
| 马拉雅拉姆语 | Malayalam | `ml` |
| Marathi | `mr` |
| 挪威语 | Norwegian | `no` |
| Polonês | Polish | `pl` |
| Português (Portugal) | Portuguese (Portugal) | `pt-PT` |
| Romeno | Romanian | `ro` |
| Russo | Russian | `ru` |
| 塞尔维亚语 | Serbian | `sr` |
| Português (Brasil) | Portuguese (Brazil) | `pt-BR` |
| 中文（台湾） | Chinese (Taiwan) | `zh-TW` | | Português (Portugal) | Portuguese (Portugal) | `pt-PT` |
| 中文（香港） | Chinese (Hong Kong) | `zh-HK` | |  |  |  |
| 日本語 | Japanese | `ja` | |  |  |  |
| 한국어 | Korean | `ko` | |  |  |  |

### Translated markdown:

| Chinês (China) | Chinese (PRC) | `zh-CN` | | Português (Brasil) | Portuguese (Brazil) | `pt-BR` |
| Chinês (Taiwan) | Chinese (Taiwan) | `zh-TW` | | Português (Portugal) | Portuguese (Portugal) | `pt-PT` |
| Chinês (Hong Kong) | Chinese (Hong Kong) | `zh-HK` | |  |  |  |
| Japonês | Japanese | `ja` | |  |  |  |
| Coreano | Korean | `ko` | |  |  |  |
| Eslovaco | Slovak | `sk` |
| Esloveno | Slovenian | `sl` |
| Espanhol | Spanish | `es` |
| Suaíli | Swahili | `sw` |
| Sueco | `sv` |
| 泰卢固语 | Telugu | `te` |
| 土耳其语 | Turkish | `tr` |
| Telugu | `te` |
| 泰语 | Thai | `th` |
| Chinês (Taiwan) | Chinese (Taiwan) | `zh-TW` |
| 乌克兰语 | Ukrainian | `uk` |
| Urdu | Urdu | `ur` |
| Ucraniano | Ukrainian | `uk` |
| Vietnamita | Vietnamese | `vi` |
| Galês | `cy` |

#### DeepL

Fonte <https://developers.deepl.com/docs/resources/supported-languages>, organizado por GPT-4o.

| Rótulo em português | Rótulo | `Código do idioma`| Suporta |
| --- | --- | --- | --- |
| Árabe | Arabic | `AR` | `source`, `target` |
| Búlgaro | Bulgarian | `BG` | `source`, `target` |
| Tcheco | Czech | `CS` | `source`, `target` |
| Dinamarquês | Danish | `DA` | `source`, `target` |
| 德语 | German | `DE` | `source`, `target` |
| Grego | Greek | `EL` | `source`, `target` |
| Inglês | `EN` | `source`, `target` |
| Inglês (Britânico) | English (British) | `EN-GB` | `target` |
| 英语（美国） | English (American) | `EN-US` | `target` |
| Espanhol | Spanish | `ES` | `source`, `target` |
| Estoniano | Estonian | `ET` | `source`, `target` |
| Finlandês | Finnish | `FI` | `source`, `target` |
| 法语 | Francês | `FR` | `source`, `target` |
| Húngaro | `HU` | `source`, `target` |
| Indonésio | Indonesian | `ID` | `source`, `target` |
| Italiano | Italian | `IT` | `source`, `target` |
| Japonês | Japanese | `JA` | `source`, `target` |
| Coreano | `KO` | `source`, `target` |
| Lituano | Lithuanian | `LT` | `source`, `target` |
| Letão | Latvian | `LV` | `source`, `target` |
| 挪威博克马尔语 | Norwegian Bokmål | `NB` | `source`, `target` |
| Holandês | Dutch | `NL` | `source`, `target` |
|  Polonês  | Polish | `PL` | `source`, `target` |
| Português | Portuguese | `PT` | `source`, `target` |
| Português (Brasil) | Portuguese (Brazilian) | `PT-BR` | `target` |
| Português (Europeu) | Portuguese (European) | `PT-PT` | `target` |
| Romeno | Romanian | `RO` | `source`, `target` |
| Russo | Russian | `RU` | `source`, `target` |
| Eslovaco | Slovak | `SK` | `source`, `target` |
| Esloveno | Slovenian | `SL` | `source`, `target` |
| Sueco | Swedish | `SV` | `source`, `target` |
| Turco | Turkish | `TR` | `source`, `target` |
| 乌克兰语 | Ukrainian | `UK` | `source`, `target` |
| 中文 | Chinês | `ZH` | `source`, `target` |
| 简体中文 | Chinese (Simplified) | `ZH-HANS` | `target` |
| 中文（繁体） | Chinese (Traditional) | `ZH-HANT` | `target` |

<div align="right"> 
<h6><small>Parte do conteúdo desta página foi traduzida pelo GPT e pode conter erros.</small></h6>